@@ -6,6 +6,7 @@ import pickle
 from contextlib import contextmanager
 from itertools import product
 
+import cloudpickle
 from atomicwrites import AtomicWriter
 
 
@@ -46,7 +47,7 @@ def save(fname, data, compress=True):
     if dirname:
         os.makedirs(dirname, exist_ok=True)
 
-    blob = pickle.dumps(data, protocol=pickle.HIGHEST_PROTOCOL)
+    blob = cloudpickle.dumps(data, protocol=pickle.HIGHEST_PROTOCOL)
     if compress:
         blob = gzip.compress(blob)
 
@@ -58,7 +59,7 @@ def load(fname, compress=True):
     fname = os.path.expanduser(fname)
     _open = gzip.open if compress else open
     with _open(fname, "rb") as f:
-        return pickle.load(f)
+        return cloudpickle.load(f)
 
 
 def copy_docstring_from(other):
